.. mrdja documentation master file, created by
   sphinx-quickstart on Thu Mar 30 22:59:28 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mrdja's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodapi:: sampling

.. automodapi:: ransac
.. automodapi:: coreransac
.. automodapi:: coreransaccuda
.. automodapi:: coreransacutils

.. automodapi:: procrustes

.. highlight:: python

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
